Module blaxel.models.repository
===============================

Classes
-------

`Repository(type_: blaxel.types.Unset | str = <blaxel.types.Unset object>, url: blaxel.types.Unset | str = <blaxel.types.Unset object>)`
:   Repository
    
    Attributes:
        type_ (Union[Unset, str]): Repository type
        url (Union[Unset, str]): Repository URL
    
    Method generated by attrs for class Repository.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `type_: blaxel.types.Unset | str`
    :

    `url: blaxel.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :